/********************************************************************************
 Author : CAC (China Applications Support Team) 

 Date :   May, 2014

 File name :  ADE7913.c 

 Description :	 read 100 samples from ADE7913 with 1kHz output frequency                 

 Hardware plateform : 	EVAL-ADuCM360MKZ and EVAL-ADE7913EBZ 
 Connection:
                 EVAL-ADuCM360MKZ       EVAL-ADE7913EBZ 
                               
                 P1.4:MISO,             MISO             
                 P1.5:SCLK,             SCLK                                                            
                 P1.6:MOSI,             MOSI
                 P1.7:CS,               CS
                 P2.0                   DREADY
********************************************************************************/

#include <ADuCM360.h>

#include "UrtLib.h"
#include "ClkLib.h"
#include "WdtLib.h"
#include "IntLib.h"
#include "DioLib.h"
#include "SpiLib.h"

#include "ADE7913.h"
#include "ADuCM360Driver.h"

unsigned int CurrentBuffer[100];
unsigned int Voltage1Buffer[100];

/*******************************************************************
  @brief int main (void)
         read 100 samples from ADE7913 with 1kHz output frequency  
  @param
         none
  @return              
         none
         
  @HardwarePlateform : 	EVAL-ADuCM360MKZ and EVAL-ADE7913EBZ 
  
  @Connection:
                 EVAL-ADuCM360MKZ       EVAL-ADE7913EBZ 
                               
                 P1.4:MISO,             MISO             
                 P1.5:SCLK,             SCLK                                                            
                 P1.6:MOSI,             MOSI
                 P1.7:CS,               CS
                 P2.0                   DREADY
*******************************************************************/
int main (void)
{  
    unsigned int    StatusValue = 0;
    unsigned int    SampleIndex;
    OutputRegisters DataReadValue; 
  
    ADuCM360Initialise();        
    Delay1(20000);      //wait for ADE7913 nonisolated side and isolated side ready   

    do
    {
        StatusValue = ADE7913ReadOperation(STAUTS0,1); //To determine when the ADE7913 device is ready to accept commands
    }while((StatusValue&0x01) == 0x01);                //read the STATUS0 register until Bit 0 (RESET_ON) is cleared to 0                                                               

    ADE7913WriteOperation(LOCK,0x9C);          //if the registers are protected first unlock the registers by writing lock = 0x9C 
    ADE7913WriteOperation(CONFIG,0x40);        //software reset  
    Delay1(20000);
    
    do
    {
        StatusValue = ADE7913ReadOperation(STAUTS0,1); //check the STATUS0 register 
    }while((StatusValue&0x01) == 0x01);
      
    ADE7913WriteOperation(CONFIG,0x30);          //select the ADC output frequency 1 kHz, 1 ms period    
    ADE7913WriteOperation(EMI_CTRL,0xFF);
    ADE7913WriteOperation(LOCK,0xCA);            //protect the user accessible and internal configuration registers
    Delay1(5000);                                //a short delay

    
    for (SampleIndex=0; SampleIndex<100; SampleIndex++)
    {
        do
        {
            StatusValue = DioRd(pADI_GP2);
        }while((StatusValue&0x01) == 0x01);       //wait until DREADY to low
                                                  //DREADY provides an active low pulse for 64 CLKIN cycles (15.625us at CLKIN= 4.096 MHz)
        
        DataReadValue = ADE7913BurstRead();       //read registers in SPI burst mode
        
        CurrentBuffer[SampleIndex]  = DataReadValue.Current;
        Voltage1Buffer[SampleIndex] = DataReadValue.Voltage1;        
    }
    
    while(1)
    { 
    }
}


